/*----------------------------------------------------------------------------------*/
/*	Copyright (C) Endress+Hauser Metechnik GmbH+Co (2000). All Rights Reserved		*/
/*	Product:		SIMATIC PDM														*/
/*                                                          						*/
/*	Device:			Hydrostatic Level DEVICE for PROFIBUS PA						*/
/*	Description:	Device Description												*/
/*	Dictionary:		SIPADC01.dct, EHPA__DeltapilotS_P3_00.dct						*/
/*                                                          						*/
/*  $Revision:1.2$									*/
/*  $Date: 06.02.2002									*/
/*  Obere Revision fr QVCS, untere fr DD, unten die aktuelle angeben 			*/ 
/*  Revision:1.2									*/
/*  Date: 06.02.2002									*/
/*----------------------------------------------------------------------------------*/
/* Date:                09.05.2001													*/
/* Author:              J. Flegel / ICS GmbH										*/
/* Changed Function(s): Change001 Reset Function									*/
/*----------------------------------------------------------------------------------*/
/* Date:                27.09.2001													*/
/* Author:              J. Flegel / ICS GmbH										*/
/* Changed Function(s): Change002 Ident-Checks aktiviert, Dict.-Text				*/
/*----------------------------------------------------------------------------------*/
/* Date:                06.02.2002													*/
/* Author:              Frank Birgel / Process Solutions										*/
/* Changed Function(s): Bi V1.2, herstellerspezifische Parameter aus Profilansicht entfernt*/
/*                      Linearisierungstabelle aus Upload entfernt*/
/*----------------------------------------------------------------------------------*/

MANUFACTURER	0x11,
DEVICE_TYPE		0x0B,
DEVICE_REVISION 1,
DD_REVISION		1

#ifndef ID_FC_ERROR
#define	ID_FC_ERROR			3000
#endif

#include "SIPAST_CommError.inc"
#include "SIPAST_Macros_300.inc"

//Change002 Start
#define ENABLE_IDENTCHECK
#define DEFAULT_MANUFACTURER_ID	17
#define CHECK_PROFILE_REV	768
#define CHECK_DEVICE_TYPE "FEB 24"
#include "SIPAST.inc"
//Change002 End

#include "SI_FileM.inc"
#include "SI_HlpM.inc"
#include "SI_OptM.inc"

#define YT1_LABEL	[std_V0H0]
#define YT1_VALUE	trans1_primary_value_value
#define	YT1_LRV		func1_AI_pv_lower_range_value
#define YT1_URV		func1_AI_pv_upper_range_value

#define YT2_LABEL	[std_V0H9]
#define YT2_VALUE	trans1_level
#define	YT2_LRV		trans1_level_lo
#define YT2_URV		trans1_level_hi

#define YT3_LABEL	[std_V3H6]
#define YT3_VALUE	trans1_sensor_value
#define	YT3_LRV		trans1_sensor_low_limit
#define YT3_URV		trans1_sensor_high_limit

#define YT4_LABEL	[func_out_value]
#define YT4_VALUE	func1_AI_out_value
#define	YT4_LRV		func1_AI_out_lower_range_value
#define YT4_URV		func1_AI_out_upper_range_value

#include "SI_YT.inc"



/************************************************************************************/

#define	FLOAT_MIN	-3.4E+38
#define	FLOAT_MAX	 3.4E+38


/************************************************************************************/
/*    Physical Block																*/
/************************************************************************************/

/*
#define	PHYS_ADDITIONAL_PARAMETER			Tab_spec_parameter 
Bi 06.02.2002 V1.2*/
#define	NO_phys_local_operation_enable

#define	MANUFACTURER_SPECIFIC_phys_factory_reset	\
		{	333,	[phys_eh_reset_333]		},		\
		{	7864,	[phys_eh_reset_7864]	}

#define DEFAULT_phys_ident_number	1

#include "SIPASTPB_300.inc"

#include "EHPA__PB_DeltapilotS_P3_00.inc"

/************************************************************************************/
/*    Function Block                                                   				*/
/************************************************************************************/

#define DEFAULT_UPPER_VAL	DEFAULT_VALUE 100 ;

#define DEFAULT_LOWER_VAL	DEFAULT_VALUE 0 ;

//#define FUNC1_TITLE	[trans_blk_parent_class_PRES]

//#define FUNC1_DEFAULT_UNIT		1137

/* gibt's nicht mehr:
#define	FUNC1_CHANNEL_PRIMARY				0x0108 // 0x01 TrdId; 0x08 => 8 => PV
#define FUNC1_CHANNEL_PRIMARY_TEXT			[trans_value]
*/
#define FUNC1_CHANNEL_LIST									\
		{ 0x0108, [trans_value] },							\
		{ 0x010A, [trans_lev_level] },						\
		{ 0x010C, [trans_lev_sensor_value] },				\
		{ 0x010E, [trans_secondary_value_1_value] },		\
		{ 0x0120, [trans_lev_temperature] }


// redefined Macros
//#include "EHPAST_Macros_300.inc"

#include "SIPASTAI_300.inc"

/************************************************************************************/
/*    Transducer Block: Level Transmitter						   					*/
/************************************************************************************/

#define	DEF_VALID_IF_PA_SELECT_V0H0_IS_ZERO					\
		VALIDITY	IF (phys_pa_select_v0h0 == 0)			\
		{													\
			TRUE;											\
		}													\
		ELSE												\
		{													\
			FALSE;											\
		}

#define DEF_VALID_PRIMARY_VALUE	DEF_VALID_IF_PA_SELECT_V0H0_IS_ZERO

#define	DEF_VALID_IF_NOT_CAL_TYPE_IS_PRESS					\
		VALIDITY	IF (trans1_calibration_type == 3)		\
		{													\
			FALSE;											\
		}													\
		ELSE												\
		{													\
			TRUE;											\
		}

#define	DEF_VALID_IF_CAL_TYPE_IS_LEVEL						\
		VALIDITY	IF (trans1_calibration_type == 1)		\
		{													\
			TRUE;											\
		}													\
		ELSE												\
		{													\
			FALSE;											\
		}

#define	DEF_VALID_IF_CAL_TYPE_IS_DRY_CAL					\
		VALIDITY	IF ((trans1_calibration_type == 0)		\
					||	(trans1_calibration_type == 2))		\
		{													\
			TRUE;											\
		}													\
		ELSE												\
		{													\
			FALSE;											\
		}


#define	DEF_VALID_TRANS_PRIMARY_VALUE_UNIT	DEF_VALID_IF_NOT_CAL_TYPE_IS_PRESS
#define	DEF_VALID_TRANS_LEVEL				DEF_VALID_IF_NOT_CAL_TYPE_IS_PRESS
#define	DEF_VALID_TRANS_LEVEL_UNIT			DEF_VALID_IF_CAL_TYPE_IS_LEVEL
#define	DEF_VALID_TRANS_TAB_ENTRY			DEF_VALID_IF_NOT_CAL_TYPE_IS_PRESS
#define	VALID_LEVEL_HYDRO					TRUE
#define	DEF_VALID_TRANS_LIN_TYPE			DEF_VALID_IF_NOT_CAL_TYPE_IS_PRESS
#define	DEF_VALID_TRANS_LIN_DIAMETER		DEF_VALID_IF_NOT_CAL_TYPE_IS_PRESS
#define	DEF_VALID_TRANS_LIN_VOLUME			DEF_VALID_IF_NOT_CAL_TYPE_IS_PRESS
#define DEF_VALID_TRANS_TAB_X_Y_VALUE		DEF_VALID_IF_NOT_CAL_TYPE_IS_PRESS
#define DEF_VALID_TRANS_TAB_NUMBER			DEF_VALID_IF_NOT_CAL_TYPE_IS_PRESS


#define	DEF_TRANS_BLK_CLASS											\
		DEFAULT_VALUE	4;											\
		{	1,		[trans_pres_blk_class_DIFF]					},	\
		{	2,		[trans_pres_blk_class_ABS]					},	\
		{	3,		[trans_pres_blk_class_GAGE]					},	\
		{	4,		[trans_pres_blk_class_PRESSURE_LEVEL_FLOW]	},	\
		{	250,	[not_used] 									},	\
		{	251,	[none]										},	\
		{	252,	[unknown]									},	\
		{	253,	[special]									}


		//DEFAULT_VALUE	1137 ;							
#define	DEF_PRESSURE_UNIT								\
		/*	Press	*/									\
		{ 1138, [unit_1138],	[unit_1138_help]	},	\
		{ 1137, [unit_1137],	[unit_1137_help]	},	\
		{ 1521, [unit_1521],	[unit_1521_help]	},	\
		{ 1149, [unit_1149],	[unit_1149_help]	},	\
		{ 1141, [unit_1141],	[unit_1141_help]	},	\
		{ 1152, [unit_1152],	[unit_1152_help]	},	\
		{ 1146, [unit_1146],	[unit_1146_help]	},	\
		{ 1130, [unit_1130],	[unit_1130_help]	},	\
		{ 1132, [unit_1132],	[unit_1132_help]	},	\
		{ 1136, [unit_1136],	[unit_1136_help]	},	\
		{ 1157, [unit_1157],	[unit_1157_help]	},	\
		{ 1155, [unit_1155],	[unit_1155_help]	},	\
		{ 1144, [unit_1144],	[unit_1144_help]	},	\
		{ 1145, [unit_1145],	[unit_1145_help]	},	\
		{ 1522, [unit_1522],	[unit_1522_help]	},	\
		{ 1523, [unit_1523],	[unit_1523_help]	}

		//DEFAULT_VALUE	1342 ;							
#define	DEF_TRANS_LEVEL_VOLUME_UNIT						\
		/*	Level	*/									\
		{ 1342, [unit_1342],	[unit_1342_help]	},	\
		{ 1010, [unit_1010],	[unit_1010_help]	},	\
		{ 1012, [unit_1012],	[unit_1012_help]	},	\
		{ 1524, [unit_1524],	[unit_1524_help]	},	\
		{ 1018, [unit_1018],	[unit_1018_help]	},	\
		{ 1019, [unit_1019],	[unit_1019_help]	},	\
		{ 1038, [unit_1038],	[unit_1038_help]	},	\
		{ 1041, [unit_1041],	[unit_1041_help]	},	\
		{ 1034, [unit_1034],	[unit_1034_help]	},	\
		{ 1035, [unit_1035],	[unit_1035_help]	},	\
		{ 1036, [unit_1036],	[unit_1036_help]	},	\
		{ 1043, [unit_1043],	[unit_1043_help]	},	\
		{ 1048, [unit_1048],	[unit_1048_help]	},	\
		{ 1049, [unit_1049],	[unit_1049_help]	},	\
		{ 1088, [unit_1088],	[unit_1088_help]	},	\
		{ 1092, [unit_1092],	[unit_1092_help]	},	\
		{ 1094, [unit_1094],	[unit_1094_help]	},	\
		{ 1095, [unit_1095],	[unit_1095_help]	},	\
		{ 1997, [special]							}


#define	DEF_DRY_CALIBRATION_UNIT						\
		/*	dry calibration	*/							\
		{ 1010, [unit_1010],	[unit_1010_help]	},	\
		{ 1012, [unit_1012],	[unit_1012_help]	},	\
		{ 1018, [unit_1018],	[unit_1018_help]	},	\
		{ 1019, [unit_1019],	[unit_1019_help]	}

#define	DEF_TRANS_DRY_CALIBRATION_UNIT					\
		DEFAULT_VALUE	1010;							\
		DEF_DRY_CALIBRATION_UNIT


// E+H specific unit list used in profil DD
#define	DEF_TRANS_SENSOR_UNIT							\
		DEFAULT_VALUE	1138;							\
		DEF_PRESSURE_UNIT

#define	DEF_TRANS_TEMPERATURE_UNIT						\
		DEFAULT_VALUE	1001;							\
		{ 1001,  [unit_1001],	[unit_1001_help]	},	\
		{ 1002,  [unit_1002],	[unit_1002_help]	}

#define DEF_TYPE_ATTRIBUT DISPLAY_FORMAT	\
		SELECT(trans1_display_format_V0H3)	\
		{									\
			CASE 0:		".0f";				\
			CASE 1:		".1f";				\
			CASE 2:		".2f";				\
			CASE 3:		".3f";				\
			CASE 4:		".4f";				\
			CASE 5:		".5f";				\
			CASE 6:		".6f";				\
			CASE 7:		".7f";				\
		}

#define	DEF_TRANS_PRIMARY_VALUE_UNIT					\
	    DEFAULT_VALUE									\
		SELECT(trans1_calibration_type)					\
		{												\
			CASE 0	:	1010;							\
			CASE 1	:	1342;							\
			CASE 2	:	1342;							\
			CASE 3	:	1138;							\
			DEFAULT:	1342;							\
		}												\
		SELECT(trans1_calibration_type)					\
		{												\
			CASE 0	:	DEF_DRY_CALIBRATION_UNIT		\
			CASE 1	:	DEF_TRANS_LEVEL_VOLUME_UNIT		\
			CASE 2	:	{ 1342, [unit_1342],	[unit_1342_help]	}	\
			CASE 3	:	DEF_PRESSURE_UNIT		\
			DEFAULT	:	DEF_TRANS_LEVEL_VOLUME_UNIT		\
		}												\

#define	DEF_TRANS_LEVEL_UNIT							\
	    DEFAULT_VALUE	1342;							\
		DEF_TRANS_LEVEL_VOLUME_UNIT

#define	DEF_TRANS_SECONDARY_VALUE_1_UNIT				\
	    DEFAULT_VALUE	1342;							\
		DEF_TRANS_LEVEL_VOLUME_UNIT

#define	DEF_TRANS_SECONDARY_VALUE_2_UNIT				\
		DEFAULT_VALUE	1138;							\
		DEF_PRESSURE_UNIT

#define	DEF_TRANS_CALIBRATION_TYPE						\
	    DEFAULT_VALUE		1;							\
		{ 1,	[enum_eh_level]},						\
		{ 0,	[enum_eh_dry_h]},						\
		{ 2,	[enum_eh_dry_per_cent]},				\
		{ 3,	[enum_eh_press]}

#define	OPT_LINTABLE
#define LIN_TABLE_USER	((trans1_lin_type == 1) || (trans1_lin_type == 240) || (trans1_lin_type == 241))

#define	DEF_TRANS_LIN_TYPE										\
		DEFAULT_VALUE	0;										\
		{ 0,	[linear],			[linear_help]		},		\
		{ 1,	[lin_mode_act_enum]						},		\
		{ 240,	[lin_mode_man_enum]						},		\
		{ 241,	[lin_mode_aut_enum]						},		\
		{ 242,	[lin_mode_del_enum]						},		\
		{ 20,	[lin_mode_CYLINDRIC_LYING_CONTAINER]	}


/*
#define	TRANS_S_SPEC_TRANS1_PARAMETER	Tab_s_spec_trans1_parameter
#define	TRANS_M_SPEC_TRANS1_PARAMETER	Tab_m_spec_trans1_parameter
06.02.2002 Bi V1.2*/
#ifdef OPT_LINTABLE
#define	TRANS_S_SPEC_TRANS1_TAB_COORDINATE	Tab_s_input_table_coordinate,

#define ATTR_trans1_tab_actual_number	\
	POST_READ_ACTIONS					\
	{									\
		method_get_actual_number		\
	}

#endif	//ifdef OPT_LINTABLE


#define NO_RELATION_TB_LEVEL_UNIT
#define NO_trans1_min_temperature

// Transducer Block 1 Profil Parameter (Mand + Opt)
#include "EHPASTTL_300.inc"

// Transducer Block 1 Manufacturer Parameter (Spec)
#include "EHPA__TB_DeltapilotS_P3_00.inc"

#ifdef OPT_LINTABLE
// Index of TAB_X_Y_VALUE in Level Transducer Block
#define DEF_COMMAND_ADR_INDEX	INDEX 37;
// Transducer Block 1 Coordinate Tables
#include "SIPA__Tables.inc"
#endif	//ifdef OPT_LINTABLE

#if 0																/* !!! not implemented */
/********************************************************************/
/*		Refresh relations											*/
/********************************************************************/

REFRESH primary_value_conditions
{
	trans1_primary_value_unit:

	func1_AI_pv_upper_range_value,
	func1_AI_pv_lower_range_value
}

REFRESH out_value_conditions
{
	func1_AI_out_unit,
	func1_AI_out_decimal_point:

	func1_AI_out_upper_range_value,
	func1_AI_out_lower_range_value,
	func1_AI_alarm_hys,
	func1_AI_hi_hi_lim,
	func1_AI_hi_lim,
	func1_AI_lo_lim,
	func1_AI_lo_lo_lim
}
#endif


/*******************************************************************************/
/*****	MENU Bar  **************************************************************/
/*******************************************************************************/

MENU Menu_Main_Specialist
{
	LABEL		[main_menu];
	ITEMS
	{
		Menu_File,
		Menu_S_Device,
		Menu_S_View,
		Menu_Options,
		Menu_Help
	}
}

MENU Menu_Main_Maintenance
{
	LABEL		[main_menu];
	ITEMS
	{
		Menu_File,
		Menu_M_Device,
		Menu_M_View,
		Menu_M_Options,
		Menu_Help
	}
}


/*---------------------------------------------------------------------*/
/*    Menu: Device													   */
/*---------------------------------------------------------------------*/

MENU Menu_S_Device
{
	LABEL		[menu_Device];
	ITEMS
	{
		std_NodeAddress,
		SEPARATOR,
		std_LoadinDevice,										
		std_LoadinPC,
		SEPARATOR,
		Menu_simulation,
		OnlineDialog_reset_eh,
		SEPARATOR,
		Tab_s_EH_v0,
		OnlineDialog_sensor_trim,
		Menu_S_Procedures,
		OnlineDialog_linearization,
		SEPARATOR,
		OnlineDialog_write_locking
	}
}

MENU Menu_S_Procedures
{
	LABEL		[menu_procedures];
	ITEMS
	{   
		IF (trans1_calibration_type != 3)
		{
			OnlineDialogLevelCalibration,
		}
		//OnlineDialogZeroOffset,
		meth_set_unit_to_bus
	}
}

MENU Menu_M_Procedures
{
	LABEL		[menu_procedures];
	ITEMS
	{   
		OnlineDialogLevelCalibration,
		//OnlineDialogZeroOffset,
		meth_set_unit_to_bus
	}
}

MENU Menu_M_Device
{
	LABEL		[menu_Device];
	ITEMS
	{
		std_LoadinDevice,										
		std_LoadinPC,
		SEPARATOR,
		Menu_M_Procedures
	}
}

METHOD std_NodeAddress
{
	LABEL		[menu_Device_NodeAddress];
	DEFINITION
	{
	}
}

METHOD std_LoadinDevice
{
	LABEL		[menu_Device_LoadinDevice];
	DEFINITION
	{
	}
}

METHOD std_LoadinPC
{
	LABEL		[menu_Device_LoadinPC];
	DEFINITION
	{
	}
}

/*---------------------------------------------------------------------*/
/*    Menu: View													   */
/*---------------------------------------------------------------------*/

MENU Menu_S_View
{
	LABEL		[menu_View];
	ITEMS
	{
		OnlineWindow_display,
		OnlineWindow_yt,
		OnlineWindow_S_alarm_func1,
		OnlineWindow_diagnosis,
		SEPARATOR,
		OnlineWindow_indicators,
		SEPARATOR,
		std_Funktionsleiste,
		std_Statuszeile,
		SEPARATOR,
		std_Update
	}
}

MENU Menu_M_View
{
	LABEL		[menu_View];
	ITEMS
	{
		OnlineWindow_display,
		OnlineWindow_yt,
		OnlineWindow_S_alarm_func1,
		OnlineWindow_diagnosis,
		SEPARATOR,
		OnlineWindow_indicators,
		SEPARATOR,
		std_Funktionsleiste,
		std_Statuszeile,
		SEPARATOR,
		std_Update
	}
}

METHOD std_Funktionsleiste
{
	LABEL		[menu_View_Toolbar];
	DEFINITION
	{
	}
}

METHOD std_Statuszeile
{
	LABEL		[menu_View_Statusbar];
	DEFINITION
	{
	}
}

METHOD std_Update
{
	LABEL		[menu_View_Update];
	DEFINITION
	{
	}
}

/*******************************************************************************/
/*****	Online-Windows  ********************************************************/
/*******************************************************************************/

MENU OnlineWindow_display
{
	LABEL		[menu_dialog_display];
	ITEMS
	{
		Page_display_func1,
		Page_display_measure,
		Page_display_measure_2,
	}
}

MENU Page_display_measure
{
	LABEL		[menu_dialog_display_measure];
	ITEMS
	{
		// zur korrekten Darststellung mssen folgende Parameter auf jeden Fall
		// ausgewertet werden. Falls PDM diese Parameter nicht automatisch auswertet, wird mit Hilfe
		// des "(HIDDEN)"- Attributs die Auswertung, d.h. das Lesen erzwungen, ohne die Parameter 
		// im Dialog anzuzeigen.
		trans1_calibration_type				(HIDDEN),
		trans1_lin_type						(HIDDEN),
		trans1_display_format_V0H3			(HIDDEN),
		phys_pa_select_v0h0					(HIDDEN),

		profil_par.std_V0H0,							//trans1_primary_value_value,

		IF (phys_pa_select_v0h0 == 0)
		{
			BarVal_pv_display,
			Group_display_primary,
		}
		ELSE
		{
			BarVal_pa_input_display,
			Group_display_pa_input,
		}

		IF (trans1_calibration_type == 1)
		{
			BarVal_level_display,
		}
		ELSE
		{
			IF (trans1_calibration_type != 3)
			{
				Val_level,
			}
		}
		
		Val_secondary_2,
		Val_sensor_display,
		Val_temperature

	}
}

MENU Page_display_measure_2
{
	LABEL		[menu_dialog_display_measure_secondary];
	ITEMS
	{
		Group_display_secondary,
		Group_display_secondary_2,
	}
}

MENU Bar_out_display
{
	LABEL		[func_out_value];
	ITEMS
	{
		func1_out_value,
		func1_out_lower_range_value (READ_ONLY),
		func1_out_upper_range_value	(READ_ONLY)
	}
}


MENU BarVal_pv_display
{
	LABEL		[std_V0H0];//[trans_value];
	ITEMS
	{
			profil_par.std_V0H0,						//trans1_primary_value_value,
			// Profil-Einstellungen:
			func1_AI_pv_lower_range_value (READ_ONLY),
			func1_AI_pv_upper_range_value (READ_ONLY)
	}
}

MENU BarVal_level_display
{
	LABEL		[std_V0H9];//[trans_value];
	ITEMS
	{
			profil_par.std_V0H9,						//trans1_level,
			trans1_emtpy_calibration_V0H1 (READ_ONLY),
			trans1_full_calibration_V0H2 (READ_ONLY)
	}
	//DEF_VALID_IF_CAL_TYPE_IS_LEVEL
}

MENU Val_secondary_2
{
	LABEL		[std_V0H8];
	ITEMS
	{
		profil_par.std_V0H8,
	}
}

MENU Val_level
{
	LABEL		[std_V0H9];
	ITEMS
	{
		profil_par.std_V0H9,
	}
	//DEF_VALID_IF_NOT_CAL_TYPE_IS_PRESS

}

MENU Val_sensor_display
{
	LABEL		[std_V3H6];
	ITEMS
	{
		trans1_sensor_value
	}
}

MENU Val_temperature
{
	LABEL		[std_V7H3];
	ITEMS
	{
		trans1_temperature
	}
}

MENU Group_display_primary
{
	LABEL		[std_V0H0];//[trans_value];
	ITEMS
	{
		/*
		trans1_primary_value_value,
		SEPARATOR,
		trans1_primary_value_status_quality,
		trans1_primary_value_status_limit,
		*/
		trans1_primary_value_status_quality,
		SEPARATOR,
		trans1_primary_value_status_limit,
	}
}

MENU BarVal_pa_input_display
{
	LABEL		[phys_pa_input_value];
	ITEMS
	{
		phys_pa_input_value,
		func1_AI_pv_lower_range_value (READ_ONLY),
		func1_AI_pv_upper_range_value (READ_ONLY)
	}
}

MENU Group_display_pa_input
{
	LABEL		[phys_pa_input_value];
	ITEMS
	{
		phys_pa_input_value,
		SEPARATOR,
		phys_pa_input_value_ui1,
		phys_pa_input_value_ui1_limit,
		//phys_pa_input_value_ui2, //Commuwin Parameter
	}
}

MENU Group_display_secondary
{
	LABEL		[trans_secondary_value_1_value];
	ITEMS
	{
		trans1_secondary_value_1_value,
		SEPARATOR,
		trans1_secondary_value_1_status_quality,
		trans1_secondary_value_1_status_limit
	}
}

MENU Group_display_secondary_2
{
	LABEL		[trans_secondary_value_2_value];
	ITEMS
	{
		trans1_secondary_value_2_value,
		SEPARATOR,
		trans1_secondary_value_2_status_quality,
		trans1_secondary_value_2_status_limit
	}
}

MENU OnlineWindow_diagnosis
{
	LABEL		[menu_dialog_diagnosis];
	ITEMS
	{
		Page_diagnosis_general,
		Page_diagnosis_phys_block,
		Page_diagnosis_trans_block,
		Page_diagnosis_func_block,
	}
}

MENU Page_diagnosis_general
{
	LABEL		[menu_dialog_general];
	ITEMS
	{
		phys_tag_desc			(READ_ONLY),
		phys_device_man_id,
		phys_device_id,
		phys_device_ser_num,
		phys_software_rev,
		phys_hardware_rev,
		phys_install_date		(READ_ONLY),
		phys_diagnosis,
		// manufacturer code:
		phys_matrix_error_code,
		phys_matrix_last_error_code	(READ_ONLY)
	}
}

MENU Page_diagnosis_phys_block
{
	LABEL		[blk_block_object_PHYSICAL];
	ITEMS
	{
		phys_blk_object,
		phys_blk_parent_class,
		phys_blk_class,
		phys_blk_dd_reference,
		phys_blk_dd_rev,
		phys_blk_profile,
		phys_blk_profile_rev,
		phys_st_rev,
		phys_actual_mode
	}
}

MENU Page_diagnosis_trans_block
{
	LABEL		[trans1_block];
	ITEMS
	{
		trans1_blk_object,
		trans1_blk_parent_class,
		trans1_blk_class,
		trans1_blk_dd_reference,
		trans1_blk_dd_rev,
		trans1_blk_profile,
		trans1_blk_profile_rev,
		trans1_st_rev,
		trans1_actual_mode
	}
}

MENU Page_diagnosis_func_block
{
	LABEL		[blk_block_object_FUNCTION];
	ITEMS
	{
		func1_AI_blk_object,
		func1_AI_blk_parent_class,
		func1_AI_blk_class,
		func1_AI_blk_dd_reference,
		func1_AI_blk_dd_rev,
		func1_AI_blk_profile,
		func1_AI_blk_profile_rev,
		func1_AI_st_rev,
		func1_AI_actual_mode
	}
}

MENU OnlineWindow_indicators
{
	LABEL		[menu_indicator];
	ITEMS
	{
		Page_pressure_pointer,
		Page_sens_temp_pointer
	}
}

/*******************************************************************************/
/*****	Online-Dialogs  ********************************************************/
/*******************************************************************************/

MENU Menu_simulation
{
	LABEL		[menu_dialog_simulation];
	ITEMS
	{
		OnlineDialog_simulation_func1,//OnlineDialog_simulation_output_func1_AI,
		OnlineDialog_simulation_input_trans1,

	}
}

/*XXXX
MENU OnlineDialog_simulation_output_func1_AI
{
	LABEL		[menu_dialog_simulation_output];
	HELP		[menu_dialog_simulation_output_help];
	ITEMS
	{
		Page_simulation_output_func1_AI
	}
}
*/

MENU OnlineDialog_simulation_input_trans1
{
	LABEL		[std_V9H6];
	ITEMS
	{
		Page_simulation_input_trans1
	}
}

MENU Page_simulation_input_trans1
{
	LABEL		[std_V9H6];
	ITEMS
	{
		trans1_simulation_mode_V9H6,	//V9H6
		trans1_simulation_value_V9H7,	//V9H7
	}
}


MENU OnlineDialog_reset_eh
{
	LABEL		[master_reset];
	HELP		[master_reset_help];
	ITEMS
	{
		phys_factory_reset,
		phys_diagnosis,
		method_set_eh						//Change001
	}
}

//Change001 Begin
// Auf Kundenwusch wurde Index 1 und PHYS_FACTORY_RESET_CMD entfernt;
// Wegen Termindruck nur mittels doppelter Variablendef. mglich
VARIABLE phys_factory_reset						/* optional */
{
	/* ST_REV */
	LABEL		[phys_factory_reset];
	HELP		[phys_factory_reset_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(2)
	{
		DEFAULT_VALUE	0;
		{ 0,		[no_function]			},
		//{ 1,		[factory_reset_PARAMS]	},
		//{ PHYS_FACTORY_RESET_CMD,			[phys_device_reset_cmd]	},
		{ PHYS_FACTORY_RESET_ADDRESS,		[factory_reset_ADDRESS]	}
#ifdef MANUFACTURER_SPECIFIC_phys_factory_reset
	MANUFACTURER_SPECIFIC_phys_factory_reset		
#endif
	}
	HANDLING	READ & WRITE;
}

METHOD method_set_eh
{
	LABEL		[transfer];
	HELP		[transfer_help];
	DEFINITION
	{
		
		int status;
		char sz[512] ;
		int iLen ;

		switch (phys_factory_reset)
		{
			case PHYS_FACTORY_RESET_CMD:
				get_dictionary_string(phys_device_reset_cmd, sz, iLen) ;

				#ifdef _V510_
				sz += "\r\n\r\n" ;
				sz += [note_connection_will_be_aborted] ;
				#endif

				PUT_MESSAGE (sz);
				break;

			case PHYS_FACTORY_RESET_ADDRESS:
				get_dictionary_string(factory_reset_ADDRESS, sz, iLen) ;

				#ifdef _V510_
				sz += "\r\n\r\n" ;
				sz += [note_connection_will_be_aborted] ;
				#endif

				PUT_MESSAGE (sz);
				break;

			default:;
		}
		
	}
}
//Change001 End


/*---------------------------------------------------------------------*/
/*    OnlineDialog: Level Calibration									   */
/*---------------------------------------------------------------------*/

MENU OnlineDialogLevelCalibration
{
	LABEL		[menu_level_calibration];
	ITEMS
	{
		trans1_emtpy_calibration_V0H1		(READ_ONLY),
		trans1_full_calibration_V0H2		(READ_ONLY),
		SEPARATOR,
		meth_emtpy_calibration_V0H1,
		meth_full_calibration_V0H2
	}
}

/*---------------------------------------------------------------------*/
/*    OnlineDialog: Level Calibration								   */
/*---------------------------------------------------------------------*/
/*
MENU OnlineDialogZeroOffset
{
	LABEL		[menu_zero_offset];
	ITEMS
	{
		trans1_zero_offset_V3H3				(READ_ONLY),
		//SEPARATOR,
		meth_zero_offset_V3H3,
	}
}
*/
/*---------------------------------------------------------------------*/
/*    OnlineDialog: Write Locking									   */
/*---------------------------------------------------------------------*/

/* siehe #include "SIPASTPB_300.inc"
MENU OnlineDialog_write_locking
{
	LABEL		[phys_write_locking];
	HELP		[phys_write_locking_help];
	ITEMS
	{
		phys_write_locking,
		phys_hw_write_protection,
		method_set
	}
}
*/

/*---------------------------------------------------------------------*/
/*    OnlineDialog: Linearization									   */
/*---------------------------------------------------------------------*/


MENU OnlineDialog_linearization
{
	LABEL		[menu_dialog_linearization];
	ITEMS
	{
		//Page_linearization_view,
		Page_linearization_input
	}
	DEF_VALID_IF_NOT_CAL_TYPE_IS_PRESS
}

MENU Page_linearization_view
{
	LABEL		[menu_dialog_linearization_read];
	ITEMS
	{
		trans1_calibration_type (HIDDEN,READ_ONLY),
		//trans1_volume_unit_VAH3 (HIDDEN),//trans1_primary_value_unit (HIDDEN),

		Group_linearization_status,
		profil_par.std_V2H0	(READ_ONLY),//trans1_lin_type,			//V2H0
		profil_par.std_V2H1,//trans1_tab_entry,						//V2H1
		trans1_lin_tab_level_V2H2	(READ_ONLY),//profil_par.std_V2H2,//trans1_tab_x_value		//V2H2
		trans1_lin_tab_volume_V2H3	(READ_ONLY),//profil_par.std_V2H3,//trans1_tab_y_value		//V2H2
		method_set
	}
}

MENU Page_linearization_input
{
	LABEL		[menu_input_table];//[menu_dialog_linearization_input];
	ITEMS
	{
		trans1_calibration_type (HIDDEN,READ_ONLY),

		Group_linearization_status,
		profil_par.std_V2H0,//trans1_lin_type,			//V2H0
		profil_par.std_V2H1,//trans1_tab_entry,			//V2H1
		trans1_lin_tab_level_V2H2,//profil_par.std_V2H2,//trans1_tab_x_value		//V2H2
		trans1_lin_tab_volume_V2H3,//profil_par.std_V2H3,//trans1_tab_y_value		//V2H3
		method_set
	}
}

MENU Group_linearization_status
{
	LABEL		[menu_dialog_linearization_status];
	ITEMS
	{
		trans1_tab_actual_number,
		phys_matrix_error_code,
	}
}

// --- Parameter table --------------------------------------------------------

MENU Table_Main_Specialist
{
	LABEL	phys_device_id;
	ITEMS
	{
		Tab_s_EH_Std_Matrix,
		Tab_s_PA_Profil,
	}
}

MENU Table_Main_Maintenance
{
	LABEL	phys_device_id;
	ITEMS
	{
		Tab_m_EH_Std_Matrix,
		Tab_m_PA_Profil
	}
}

MENU Tab_s_PA_Profil
{
	LABEL		[menu_table_sensor_level];
	ITEMS
	{
		Tab_s_ident,
		Tab_s_input,
		Tab_s_output,
/*		Tab_s_opconds,
		Tab_s_const,Bi V1.2*/
		Tab_s_interface,
		Tab_s_certificates
	}
}

MENU Tab_m_PA_Profil
{
	LABEL		[menu_table_sensor_level];
	ITEMS
	{
		Tab_m_ident,
		Tab_m_input,
		Tab_m_output,
/*		Tab_s_opconds,Bi V1.2*/
		Tab_m_diagnosis,
/*		Tab_m_const,Bi V1.2*/
		Tab_s_interface,
		Tab_m_certificates
	}
}


MENU Tab_s_input
{
	LABEL		[menu_input];
	ITEMS
	{

		Tab_s_trans1,
	}
}

MENU Tab_m_input
{
	LABEL		[menu_input];
	ITEMS
	{
		Tab_m_trans1,
	}
}

MENU Tab_s_output
{
	LABEL		[menu_output];
	ITEMS
	{
		Tab_s_func1,
	}
}

MENU Tab_m_output
{
	LABEL		[menu_output];
	ITEMS
	{
		Tab_m_func1
	}
}

MENU Tab_s_opconds
{
	LABEL		[menu_opcondition];
	ITEMS
	{
		Tab_s_trans1_opconds_proc
	}
}

MENU Tab_s_const
{
	LABEL		[menu_construct];
	ITEMS
	{
		Tab_s_trans1_const_design,
		Tab_s_trans1_const_proc,
	}
}

MENU Tab_m_const
{
	LABEL		[menu_construct];
	ITEMS
	{
		Tab_m_trans1_const_design,
		Tab_m_trans1_const_proc,
	}
}

MENU Tab_s_interface
{
	LABEL		[menu_interface];
	ITEMS
	{

/*		trans1_display_format_V0H3,Bi V1.2*/
		Tab_s_interface_set
	}
}

MENU Tab_s_interface_set
{
	LABEL		[menu_interface_set];
	ITEMS
	{
		trans1_cal_point_lo			(READ_ONLY),
		trans1_cal_point_hi			(READ_ONLY),
	}
}

MENU Tab_s_certificates
{
	LABEL		[menu_certificates];
	ITEMS
	{
		phys_device_certification	(READ_ONLY),
	}
}

MENU Tab_m_certificates
{
	LABEL		[menu_certificates];
	ITEMS
	{
		phys_device_certification	(READ_ONLY),
	}
}


// --- Parameter table EH --------------------------------------------------------

MENU Tab_s_EH_Std_Matrix
{
	LABEL		[menu_table_EH_Std_Matrix];
	ITEMS
	{
		Tab_s_EH_v0,
		//Tab_s_EH_v1, //not used
		Tab_s_EH_v2,
		Tab_s_EH_v3,
		//Tab_s_EH_v4, //not used
		//Tab_s_EH_v5, //not used
		Tab_s_EH_v6,
		Tab_s_EH_v7,
		//Tab_s_EH_v8, //not used
		Tab_s_EH_v9,
		Tab_s_EH_vA,
	}
}

MENU Tab_m_EH_Std_Matrix
{
	LABEL		[menu_table_EH_Std_Matrix];
	ITEMS
	{
		Tab_m_EH_v0,
//Change001 Begin
		Tab_m_EH_v2,
		Tab_m_EH_v3,
		Tab_m_EH_v6,
		Tab_s_EH_v7,
		Tab_m_EH_v9,
		Tab_m_EH_vA,
//Change001 End
	}
}

MENU Tab_s_EH_v0
{
	LABEL		[menu_table_EH_v0];
	ACCESS		ONLINE;
	ITEMS
	{
		// damit der Online-Dialog funktioniert:
		trans1_calibration_type				(HIDDEN,READ_ONLY),
		trans1_lin_type						(HIDDEN,READ_ONLY),
		trans1_display_format_V0H3			(HIDDEN,READ_ONLY),

		std_V0H0,//trans1_primary_value_value				//V0H0										//V0H0
		std_V0H1,//trans1_emtpy_calibration_V0H1,			//V0H1
		std_V0H2,//trans1_full_calibration_V0H2,			//V0H2
		trans1_display_format_V0H3,							//V0H3
		trans1_damping_V0H4,								//V0H4
		profil_par.std_V0H5,//func1_AI_pv_lower_range_value	//V0H5
		profil_par.std_V0H6,//func1_AI_pv_upper_range_value //V0H6
		trans1_fail_safe_V0H7,								//V0H7
		std_V0H8											//V0H8
		std_V0H9,											//V0H9
	}
}


//Change001 Begin
MENU Tab_m_EH_v0
{
	LABEL		[menu_table_EH_v0];
	ITEMS
	{
		// damit der Online-Dialog funktioniert:
		trans1_calibration_type				(HIDDEN,READ_ONLY),
		trans1_lin_type						(HIDDEN,READ_ONLY),
		trans1_display_format_V0H3			(HIDDEN,READ_ONLY),


		std_V0H0,											//V0H0
		std_V0H1,//trans1_emtpy_calibration_V0H1,			//V0H1
		std_V0H2,//trans1_full_calibration_V0H2,			//V0H2
		trans1_display_format_V0H3	(READ_ONLY),			//V0H3
		trans1_damping_V0H4			(READ_ONLY),			//V0H4
		profil_par.std_V0H5			(READ_ONLY),			//V0H5
		profil_par.std_V0H6			(READ_ONLY),			//V0H6
		trans1_fail_safe_V0H7		(READ_ONLY),			//V0H7
		std_V0H8											//V0H8
		std_V0H9											//V0H9
	}
}
//Change001 End

/*
MENU Tab_s_EH_v1
{
	LABEL		[menu_table_EH_v1];
	ITEMS
	{
	}
}
*/

MENU Tab_s_EH_v2
{
	LABEL		[menu_table_EH_v2];
	ITEMS
	{
		trans1_calibration_type (HIDDEN,READ_ONLY),		// damit der Online-Dialog funktioniert!

		profil_par.std_V2H0,//trans1_lin_type,			//V2H0
		std_V2H1,//trans1_tab_entry,					//V2H1
		std_V2H2,//trans1_tab_x_value					//V2H2
		std_V2H3,//trans1_tab_y_value					//V2H3
		profil_par.std_V2H4,//trans1_lin_diameter,		//V2H4
		profil_par.std_V2H5,//trans1_lin_volume,		//V2H5
	}
}

//Change001 Begin
MENU Tab_m_EH_v2
{
	LABEL		[menu_table_EH_v2];
	ITEMS
	{
		trans1_calibration_type (HIDDEN,READ_ONLY),		// damit der Online-Dialog funktioniert!

		profil_par.std_V2H0	(READ_ONLY),//trans1_lin_type,			//V2H0
		std_V2H1,//trans1_tab_entry,								//V2H1
		std_V2H2,//trans1_tab_x_value								//V2H2
		std_V2H3,//trans1_tab_y_value								//V2H3
		profil_par.std_V2H4	(READ_ONLY),//trans1_lin_diameter,		//V2H4
		profil_par.std_V2H5	(READ_ONLY),//trans1_lin_volume,		//V2H5
	}
}
//Change001 End

MENU Tab_s_EH_v3
{
	LABEL		[menu_table_EH_v3];
	ITEMS
	{
		profil_par.std_V3H0//trans1_calibration_type,	//V3H0
		trans1_dry_calibration_unit_V3H1,				//V3H1
		trans1_density_factor_V3H2,						//V3H2
		trans1_zero_offset_V3H3,						//V3H3
		profil_par.std_V3H4,							//V3H4
#ifndef NO_trans1_temperature_unit
		profil_par.std_V3H5//trans1_temperature_unit	//V3H5
#endif	//ifndef NO_trans1_temperature_unit
		std_V3H6,//trans1_sensor_value,					//V3H6
		profil_par.std_V3H7,//trans1_sensor_offset,		//V3H7
	}
}

//Change001 Begin
MENU Tab_m_EH_v3
{
	LABEL		[menu_table_EH_v3];
	ITEMS
	{
		profil_par.std_V3H0	(READ_ONLY),//trans1_calibration_type,	//V3H0
		trans1_dry_calibration_unit_V3H1	(READ_ONLY),			//V3H1
		trans1_density_factor_V3H2	(READ_ONLY),					//V3H2
		trans1_zero_offset_V3H3	(READ_ONLY),						//V3H3
		profil_par.std_V3H4	(READ_ONLY),							//V3H4
#ifndef NO_trans1_temperature_unit
		profil_par.std_V3H5	(READ_ONLY)//trans1_temperature_unit	//V3H5
#endif	//ifndef NO_trans1_temperature_unit
		std_V3H6,//trans1_sensor_value,								//V3H6
		profil_par.std_V3H7	(READ_ONLY),//trans1_sensor_offset,		//V3H7
	}
}
//Change001 End

/* not used
MENU Tab_s_EH_v4
{
	LABEL		[menu_table_EH_v4];
	ITEMS
	{
	}
}

MENU Tab_s_EH_v5
{
	LABEL		[menu_table_EH_v5];
	ITEMS
	{
	}
}
*/

MENU Tab_s_EH_v6
{
	LABEL		[menu_table_EH_v6];
	ITEMS
	{
		profil_par.std_V6H0,//phys_ident_number,	//V6H0
		std_V6H1,//phys_pa_set_unit_to_bus,			//V6H1
		std_V6H2,//func1_AI_out_value				//V6H2
		std_V6H3,//func1_AI_out_status				//V6H3
		phys_pa_select_second_cyc_val,				//V6H4
		phys_pa_select_v0h0,						//V6H5
		std_V6H6,//phys_pa_input_value,				//V6H6
		phys_pa_profile_rev							//V6H7
		//leer										//V6H8
		//leer										//V6H9						
	}
}

//Change001 Begin
MENU Tab_m_EH_v6
{
	LABEL		[menu_table_EH_v6];
	ITEMS
	{
		profil_par.std_V6H0 (READ_ONLY),//phys_ident_number,	//V6H0
		std_V6H1,//phys_pa_set_unit_to_bus,						//V6H1
		std_V6H2,//func1_AI_out_value							//V6H2
		std_V6H3,//func1_AI_out_status							//V6H3
		phys_pa_select_second_cyc_val (READ_ONLY),				//V6H4
		phys_pa_select_v0h0 (READ_ONLY),						//V6H5
		std_V6H6,//phys_pa_input_value,							//V6H6
		phys_pa_profile_rev										//V6H7
		//leer													//V6H8
		//leer													//V6H9						
	}
}
//Change001 End

MENU Tab_s_EH_v7
{
	LABEL		[menu_table_EH_v7];
	ITEMS
	{
		profil_par.std_V7H0,//trans1_sensor_low_limit,	//V7H0
		profil_par.std_V7H1,//trans1_sensor_high_limit,	//V7H1
		std_V7H2,//trans1_max_sensor_value,				//V7H2
		std_V7H3,//trans1_temperature,					//V7H3
		std_V7H4,//trans1_max_temperature,				//V7H4
	}
}

/* not used
MENU Tab_s_EH_v8
{
	LABEL		[menu_table_EH_v8];
	ITEMS
	{
	}
}
*/

MENU Tab_s_EH_v9
{
	LABEL		[menu_table_EH_v9];
	ITEMS
	{
		phys_matrix_error_code,						//V9H0
		phys_matrix_last_error_code,				//V9H1
		phys_matrix_device_software_nr,				//V9H3
		phys_bus_address,							//V9H4
		std_V9H5,//phys_factory_reset,				//V9H5
		std_V9H6,//trans1_simulation_mode_V9H6,		//V9H6
		std_V9H7,//trans1_simulation_value_V9H7,	//V9H7
		std_V9H9									//V9H9
	}
}

//Change001 Begin
MENU Tab_m_EH_v9
{
	LABEL		[menu_table_EH_v9];
	ITEMS
	{
		phys_matrix_error_code,						//V9H0
		phys_matrix_last_error_code (READ_ONLY),	//V9H1
		phys_matrix_device_software_nr,				//V9H3
		phys_bus_address,							//V9H4
		std_V9H5,//phys_factory_reset,				//V9H5
		std_V9H6,//trans1_simulation_mode_V9H6,		//V9H6
		std_V9H7,//trans1_simulation_value_V9H7,	//V9H7
		std_V9H9									//V9H9
	}
}
//Change001 End

MENU Tab_s_EH_vA
{
	LABEL		[menu_table_EH_vA];
	ITEMS
	{
		trans1_calibration_type (HIDDEN,READ_ONLY),	// damit der Online-Dialog funktioniert!

		profil_par.std_VAH0,		//VAH0
		//nicht in der Matrix: profil_par.std_VAH1,		//VAH1
		profil_par.std_VAH2,		//VAH2
		profil_par.std_VAH3,		//VAH3
		trans1_full_density_VAH4,	//profil_par.std_VAH4,		//VAH4 Infos fehlen
		profil_par.std_VAH5,		//VAH5
		trans1_empty_pressure_VAH6,	//VAH6
		trans1_empty_density_VAH7,	//VAH7
		trans1_full_pressure_VAH8	//VAH8
		//leer						//VAH9
	}
}

//Change001 Begin
MENU Tab_m_EH_vA
{
	LABEL		[menu_table_EH_vA];
	ITEMS
	{
		trans1_calibration_type (HIDDEN,READ_ONLY),	// damit der Online-Dialog funktioniert!

		profil_par.std_VAH0 (READ_ONLY),				//VAH0
		//nicht in der Matrix: profil_par.std_VAH1,		//VAH1
		profil_par.std_VAH2 (READ_ONLY),				//VAH2
		profil_par.std_VAH3 (READ_ONLY),				//VAH3
		trans1_full_density_VAH4,						//profil_par.std_VAH4,		//VAH4 Infos fehlen
		profil_par.std_VAH5,							//VAH5
		trans1_empty_pressure_VAH6,						//VAH6
		trans1_empty_density_VAH7,						//VAH7
		trans1_full_pressure_VAH8						//VAH8
		//leer											//VAH9
	}
}
//Change001 End

/***********************************************************************/
/*    Components for standard view									   */
/***********************************************************************/

VARIABLE std_V0H0
{
	LABEL		[std_V0H0];
	CLASS		LOCAL;
	TYPE		ENUMERATED
	{
		DEFAULT_VALUE 0;
		{	0,	[std_display_enum]}
	}
	HANDLING	READ;
	DEF_VALID_PRIMARY_VALUE
}

VARIABLE std_V0H1
{
	LABEL		[std_V0H1];
	CLASS		LOCAL;
	TYPE		ENUMERATED
	{
		DEFAULT_VALUE 0;
		{	0,	[std_calibration_enum]}
	}
	HANDLING	READ;
	DEF_VALID_IF_CAL_TYPE_IS_LEVEL

}

VARIABLE std_V0H2
{
	LABEL		[std_V0H2];
	CLASS		LOCAL;
	TYPE		ENUMERATED
	{
		DEFAULT_VALUE 0;
		{	0,	[std_calibration_enum]}
	}
	HANDLING	READ;
	DEF_VALID_IF_NOT_CAL_TYPE_IS_PRESS

}

METHOD meth_abort
{
	DEFINITION
	{

		local_abort = 1; //Abbruch
		ACKNOWLEDGE([acknowledge_process_aborted]);
	}
}

METHOD meth_emtpy_calibration_V0H1
{
	LABEL		[menu_empty_calibration];
	DEFINITION
	{   
		int ret;
		long var_id[1];

		add_abort_method (meth_abort);

		// ---------- aktuellen Fllstand fr 'Fllstand leer' eintragen
		ret = ReadCommand (read_trans1_calibration_type);
		if (ret >= ID_FC_ERROR)	process_abort();

		if (trans1_calibration_type == 1)
		{
			ret = ReadCommand (read_trans1_level_unit);
			if (ret >= ID_FC_ERROR)	process_abort();
			var_id[0] = VARID(trans1_level_unit);
		}
		else
		{
			ret = ReadCommand (read_trans1_dry_calibration_unit_V3H1);
			if (ret >= ID_FC_ERROR)	process_abort();
			var_id[0] = VARID(trans1_dry_calibration_unit_V3H1);
		}

		ret = get_dev_var_value([ack_emtpy_calibration_V0H1], var_id, trans1_emtpy_calibration_V0H1);
		if (ret)	process_abort();	// ok <=> 0

		ret = WriteCommand (write_trans1_emtpy_calibration_V0H1);
		if (ret >= ID_FC_ERROR)	process_abort();

		remove_abort_method (meth_abort);
		ACKNOWLEDGE ([ack_calibration_success]);

	}
	DEF_VALID_IF_CAL_TYPE_IS_LEVEL
}

METHOD meth_full_calibration_V0H2
{
	LABEL		[menu_full_calibration];
	DEFINITION
	{   
		int ret;
		long var_id[1];

		add_abort_method (meth_abort);

		// ---------- aktuellen Fllstand fr 'Fllstand voll' eintragen
		ret = ReadCommand (read_trans1_calibration_type);
		if (ret >= ID_FC_ERROR)	process_abort();

		if (trans1_calibration_type == 1)
		{
			ret = ReadCommand (read_trans1_level_unit);
			if (ret >= ID_FC_ERROR)	process_abort();
			var_id[0] = VARID(trans1_level_unit);
		}
		else
		{
			ret = ReadCommand (read_trans1_dry_calibration_unit_V3H1);
			if (ret >= ID_FC_ERROR)	process_abort();
			var_id[0] = VARID(trans1_dry_calibration_unit_V3H1);
		}

		ret = get_dev_var_value([ack_full_calibration_V0H2], var_id, trans1_full_calibration_V0H2);
		if (ret)	process_abort();	// ok <=> 0

		ret = WriteCommand (write_trans1_full_calibration_V0H2);
		if (ret >= ID_FC_ERROR)	process_abort();

		remove_abort_method (meth_abort);
		ACKNOWLEDGE ([ack_calibration_success]);

	}
	DEF_VALID_IF_NOT_CAL_TYPE_IS_PRESS
}

METHOD meth_set_unit_to_bus
{
	LABEL		[phys_pa_set_unit_to_bus];
	DEFINITION
	{   
		int ret;

		add_abort_method (meth_abort);

		// ---------- Besttigung: Einheit bernehmen
		ret = ACKNOWLEDGE ([ack_apply_unit_to_bus]);
		if (ret)	process_abort();	// ok <=> 0
		ret = WriteCommand(write_phys_pa_set_unit_to_bus);
		if (ret >= ID_FC_ERROR)	process_abort();

	}
}

VARIABLE std_V0H8
{
	LABEL		[std_V0H8];
	CLASS		LOCAL;
	TYPE		ENUMERATED
	{
		DEFAULT_VALUE 0;
		{	0,	[std_display_enum]}
	}
	HANDLING	READ;
}

std_V0H9		LIKE VARIABLE std_V0H8
{
	REDEFINE LABEL		[std_V0H9];
	REDEFINE DEF_VALID_IF_NOT_CAL_TYPE_IS_PRESS
}

VARIABLE std_V2H1
{
	LABEL		[std_V2H1];
	CLASS		LOCAL;
	TYPE		ENUMERATED
	{
		DEFAULT_VALUE 0;
		{	0,	[std_lin_enum]}
	}
	HANDLING	READ;
	DEF_VALID_IF_NOT_CAL_TYPE_IS_PRESS
}

std_V2H2		LIKE VARIABLE std_V2H1
{
	REDEFINE LABEL		[std_V2H2];
}

std_V2H3		LIKE VARIABLE std_V2H1
{
	REDEFINE LABEL		[std_V2H3];
}

std_V3H6		LIKE VARIABLE std_V0H8
{
	REDEFINE LABEL		[std_V3H6];
}

VARIABLE std_V6H1
{
	LABEL		[phys_pa_set_unit_to_bus];
	CLASS		LOCAL;
	TYPE		ENUMERATED
	{
		DEFAULT_VALUE 0;
		{	0,	[std_calibration_enum]}
	}
	HANDLING	READ;
}

std_V6H2		LIKE VARIABLE std_V0H8
{
	REDEFINE LABEL		[std_V6H2];
}

std_V6H3		LIKE VARIABLE std_V0H8
{
	REDEFINE LABEL		[std_V6H3];
}

std_V6H6		LIKE VARIABLE std_V0H8
{
	REDEFINE LABEL		[phys_pa_input_value];
}


VARIABLE std_V7H2
{
	LABEL		[std_V7H2];
	HELP		[trans_pres_max_sensor_value_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED
	{
		DEFAULT_VALUE 0;
		{	0,	[std_min_max_enum]}
	}
	HANDLING	READ;
}

std_V7H3		LIKE VARIABLE std_V0H8
{
	REDEFINE LABEL		[std_V7H3];
}

VARIABLE std_V7H4
{
	LABEL		[std_V7H4];
	HELP		[trans_lev_max_temperature_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED
	{
		DEFAULT_VALUE 0;
		{	0,	[std_min_max_enum]}
	}
	HANDLING	READ;
}

VARIABLE std_V9H5
{
	LABEL		[std_V9H5];
	CLASS		LOCAL;
	TYPE		ENUMERATED
	{
		DEFAULT_VALUE 0;
		{	0,	[std_V9H5_enum]}
	}
	HANDLING	READ;
}

VARIABLE std_V9H6
{
	LABEL		[std_V9H6];
	CLASS		LOCAL;
	TYPE		ENUMERATED
	{
		DEFAULT_VALUE 0;
		{	0,	[std_simul_enum]}
	}
	HANDLING	READ;
}

std_V9H7		LIKE VARIABLE std_V9H6
{
	REDEFINE LABEL		[std_V9H7];
}

VARIABLE std_V9H9
{
	LABEL		[std_V9H9];
	HELP		[phys_write_locking_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED
	{
		DEFAULT_VALUE 0;
		{	0,	[std_V9H9_enum]}
	}
	HANDLING	READ;
}


COLLECTION OF VARIABLE profil_par
{
    MEMBERS
    {
		std_V0H0,		trans1_primary_value_value,			[std_V0H0];

		std_V0H5,		func1_AI_pv_lower_range_value,		[std_V0H5];
		std_V0H6,		func1_AI_pv_upper_range_value,		[std_V0H6];
		std_V0H8,		trans1_secondary_value_2_value,		[std_V0H8];
		std_V0H9,		trans1_level,						[std_V0H9];

		std_V2H0,		trans1_lin_type,					[std_V2H0];
		std_V2H1,		trans1_tab_entry,					[std_V2H1];
		std_V2H2,		trans1_tab_x_value,					[std_V2H2];
		std_V2H3,		trans1_tab_y_value,					[std_V2H3];
		std_V2H4,		trans1_lin_diameter,				[std_V2H4];
		std_V2H5,		trans1_lin_volume,					[std_V2H5];

		std_V3H0,		trans1_calibration_type,			[std_V3H0];
		std_V3H4,		trans1_sensor_unit,					[std_V3H4];
#ifndef NO_trans1_temperature_unit
		std_V3H5,		trans1_temperature_unit,			[std_V3H5];
#endif
		std_V3H6,		trans1_sensor_value,				[std_V3H6];
		std_V3H7,		trans1_sensor_offset,				[std_V3H7];

		std_V6H0,		phys_ident_number,					[std_V6H0];

		std_V7H0,		trans1_sensor_low_limit,			[std_V7H0];
		std_V7H1,		trans1_sensor_high_limit,			[std_V7H1];
		std_V7H2,		trans1_max_sensor_value,			[std_V7H2];
		std_V7H3,		trans1_temperature,					[std_V7H3];
		std_V7H4,		trans1_max_temperature,				[std_V7H4];

		std_VAH0,		phys_tag_desc,						[std_VAH0];
		//nicht in der Matrix: std_VAH1,		phys_message,						[std_VAH1];
		std_VAH2,		trans1_level_unit,					[std_VAH2];
		std_VAH3,		trans1_volume_unit_VAH3,			[std_VAH3]; // = trans1_primary_value_unit,
		std_VAH5,		phys_device_ser_num,				[std_VAH5];
	}
}


/*******************************************************************************/
/*****	Methods		************************************************************/
/*******************************************************************************/

METHOD method_set
{
	LABEL		[transfer];
	HELP		[transfer_help];
	DEFINITION
	{
	}
}

METHOD method_preset_alarm
{
	CLASS		INPUT;
	DEFINITION
	{
		float fValue;
		
		fValue = fvar_value(func1_AI_hi_hi_lim);
		fassign(func1_AI_hi_hi_lim, FLOAT_MAX);
		WriteCommand(write_func1_AI_hi_hi_lim);
		fassign(func1_AI_hi_hi_lim, fValue);
		
		fValue = fvar_value(func1_AI_lo_lo_lim);
		fassign(func1_AI_lo_lo_lim, FLOAT_MIN);
		WriteCommand(write_func1_AI_lo_lo_lim);
		fassign(func1_AI_lo_lo_lim, fValue);
	}
}

/*
METHOD meth_zero_offset_V3H3
{
	LABEL		[menu_zero_offset];
	DEFINITION
	{   
		int ret;
		long var_id[1];

		add_abort_method (meth_abort);

		// ---------- aktuellen Fllstand fr 'Fllstand voll' eintragen
		ret = ReadCommand (read_trans1_calibration_type);
		if (ret >= ID_FC_ERROR)	process_abort();

		if (trans1_calibration_type == 1)
		{
			ret = ReadCommand (read_trans1_level_unit);
			if (ret >= ID_FC_ERROR)	process_abort();
			var_id[0] = VARID(trans1_level_unit);
		}
		else
		{
			ret = ReadCommand (trans1_dry_calibration_unit_V3H1);
			if (ret >= ID_FC_ERROR)	process_abort();
			var_id[0] = VARID(trans1_dry_calibration_unit_V3H1);
		}

		ret = get_dev_var_value([ack_zero_offset_V3H3], var_id, trans1_zero_offset_V3H3);
		if (ret)	process_abort();	// ok <=> 0

		ret = WriteCommand (write_trans1_zero_offset_V3H3);
		if (ret >= ID_FC_ERROR)	process_abort();

		remove_abort_method (meth_abort);
		ACKNOWLEDGE ([ack_calibration_success]);

	}
	DEF_VALID_IF_NOT_CAL_TYPE_IS_PRESS
}
*/

/***********************************************************************/
/*    Unit relations                                                   */
/***********************************************************************/

/* Physical Block */
/* no unit relations */

/* Level Transducer Block */
UNIT TB_SENSOR_UNIT_EH
{
	trans1_sensor_unit:					//V3H4

	trans1_empty_pressure_VAH6,			//VAH6
	trans1_full_pressure_VAH8			//VAH8
}

UNIT TB_LEVEL_DRY_UNIT
{
	IF (trans1_calibration_type == 1)		//V3H0 == Level
	{
		trans1_level_unit					//VAH2
	}
	ELSE									//V3H0 != Level
	{
		trans1_dry_calibration_unit_V3H1	//V3H1
	}
	:
	
	trans1_level_offset,
	trans1_level_lo,
	trans1_level_hi,
	trans1_zero_offset_V3H3,
	trans1_full_calibration_V0H2,
	trans1_emtpy_calibration_V0H1,

}

UNIT TB_LEVEL_DRY_H_PER_CENT_UNIT
{
	SELECT (trans1_calibration_type)
	{
		CASE	1:	trans1_level_unit					//V3H0 == Level; unit = VAH2
		CASE	0:	trans1_dry_calibration_unit_V3H1	//V3H0 == Dry_h; unit = V3H1
		DEFAULT:	local_dry_calibration_per_cent_unit	//V3H0 == Dry_%; unit = %
	}
	:
	trans1_level,				//V0H9
	trans1_lin_tab_level_V2H2,	//V2H2
	trans1_tab_x_value,			//V2H2 Profilparameter = trans1_lin_tab_level_V2H2
	trans1_lin_diameter			//V2H4
}

UNIT TB_PRIMARY_UNIT
{
	trans1_volume_unit_VAH3: //trans1_primary_value_unit:
	
	trans1_lin_tab_volume_V2H3,	//V2H3
	trans1_tab_y_value,			//V2H3 Profilparameter = trans1_lin_tab_volume_V2H3
	trans1_lin_volume			//V2H5
}

VARIABLE local_dry_calibration_per_cent_unit
{
	LABEL		"local_dry_calibration_per_cent_unit";
	CLASS		CONTAINED;//LOCAL;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	1342;
		{ 1342, [unit_1342],	[unit_1342_help]	}

	}
	SCALE_ACTIONS { meth_local_dry_calibration_per_cent_unit}
}

METHOD	meth_local_dry_calibration_per_cent_unit
{
	LABEL		"meth_local_dry_calibration_per_cent_unit";
	DEFINITION
	{
		local_dry_calibration_per_cent_unit = 1342;
	}
}

// Pseudo- Kommando - notwendig fr alle UNIT-Relations
// mit local_dry_calibration_per_cent_unit
COMMAND read_local_dry_calibration_per_cent_unit
{
	BLOCK transducer_block_1;
	INDEX 65;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			local_dry_calibration_per_cent_unit
		}
	}
}

// Das gleiche fr Meter:
VARIABLE local_dry_calibration_per_meter
{
	LABEL		"local_dry_calibration_per_meter";
	CLASS		CONTAINED;//LOCAL;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	1010;
		{ 1010, [unit_1010],	[unit_1010_help]	}

	}
	SCALE_ACTIONS { meth_local_dry_calibration_per_meter}
}

METHOD	meth_local_dry_calibration_per_meter
{
	LABEL		"meth_local_dry_calibration_per_meter";
	DEFINITION
	{
		local_dry_calibration_per_meter = 1010;
	}
}

// Pseudo- Kommando - notwendig fr alle UNIT-Relations
// mit local_dry_calibration_per_meter
COMMAND read_local_dry_calibration_per_meter
{
	BLOCK transducer_block_1;
	INDEX 65;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			local_dry_calibration_per_meter
		}
	}
}


UNIT AI_UNIT_BY_CHANNEL
{
/*	func1_AI_pv_unit:	*/
	SELECT (func1_AI_channel)
	{
		CASE 0x0108:	
				IF (trans1_calibration_type == 3)						//V3H0 == Press
				{
					trans1_sensor_unit									//V3H4
				}
				ELSE
				{
					IF(trans1_lin_type == 0)							//V2H0 == linear
					{
						SELECT (trans1_calibration_type)
						{
							CASE 1:	trans1_level_unit					//VAH2
							CASE 0:	trans1_dry_calibration_unit_V3H1	//V3H1
							CASE 2:	local_dry_calibration_per_cent_unit	// %
						}
					}
					ELSE
					{
						trans1_volume_unit_VAH3 //trans1_primary_value_unit	//VAH3
					}
				}

		CASE 0x010A:	trans1_level_unit
		CASE 0x010C:	trans1_sensor_unit
#ifndef NO_trans1_secondary_value_1_unit
		CASE 0x010E:	trans1_secondary_value_1_unit
#endif
#ifndef NO_trans1_temperature_unit
		CASE 0x0120:	trans1_temperature_unit
#endif
		DEFAULT:		trans1_volume_unit_VAH3 //trans1_primary_value_unit
	}
	:
	trans1_primary_value_value,
	func1_AI_pv_upper_range_value,
	func1_AI_pv_lower_range_value,
	func1_AI_simulate_value
}


UNIT TB_SIMULATION_MODE_UNIT
{
	SELECT (trans1_simulation_mode_V9H6)
	{
		CASE 1:	trans1_sensor_unit
		CASE 2:	SELECT (trans1_calibration_type)
				{
					CASE 0:	local_dry_calibration_per_meter		// m
					CASE 2:	local_dry_calibration_per_cent_unit	// %
					DEFAULT:trans1_level_unit					//VAH2
				}
		CASE 3:	trans1_volume_unit_VAH3
		DEFAULT:trans1_level_unit
	}
	:
	trans1_simulation_value_V9H7
}


/*******************************************************************************/
/*****	Commands  **************************************************************/
/*******************************************************************************/
VARIABLE local_abort
{
	LABEL	"ABORT";
	TYPE INTEGER
	{
		DEFAULT_VALUE	0;
	}
}

METHOD pre_read_download_variables
{
	CLASS		INPUT;
	DEFINITION
	{
		int ret;

		local_abort = 0; //kein Abbruch

		add_abort_method (meth_abort);

#ifdef OPT_LINTABLE
		ret = ReadCommand(read_trans1_tab_actual_number);
		if (ret >= ID_FC_ERROR)	process_abort();
#endif

		ret = ReadCommand(read_trans1_lin_type);
		if (ret >= ID_FC_ERROR)	process_abort();

		ret = ReadCommand(read_trans1_calibration_type);
		if (ret >= ID_FC_ERROR)	process_abort();

	}
}

MENU download_variables
{
	LABEL		[menu_load_to_PC];
	PRE_READ_ACTIONS
	{
		pre_read_download_variables
	}
	ITEMS
	{
	
		IF (local_abort == 0)
		{
		/* PHYSICAL BLOCK, STANDARD PARAMETER	*/
			phys_tag_desc,
			phys_device_id,
		/* PHYSICAL BLOCK, ADDITIONAL PARAMETER	*/
			phys_descriptor,
			phys_message,
			phys_device_man_id,
			phys_device_ser_num,
			phys_software_rev,
			phys_hardware_rev,
			phys_blk_profile_rev,
			phys_st_rev,
			phys_ident_number,
			phys_install_date,
			//phys_write_locking,	//OnlineDialog_write_locking
			phys_device_certification,
		/* PHYSICAL BLOCK, SPECIFIC PARAMETER	*/
			phys_matrix_error_code,
			phys_matrix_last_error_code,
			phys_bus_address,
			phys_matrix_device_software_nr,
			//std_V6H1,								//Menu phys_pa_set_unit_to_bus,
			phys_pa_input_value,
			phys_pa_input_value_ui1,
			//phys_pa_input_value_ui2,				//Commuwin Parameter
			phys_pa_select_v0h0,
			phys_pa_profile_rev,
			phys_pa_select_second_cyc_val,

		/* TRANDSDUCER BLOCK, STANDARD PARAMETER	*/
			trans1_primary_value_unit,
			IF (trans1_calibration_type != 3)
			{
				//trans1_primary_value_unit,
				trans1_volume_unit_VAH3,//trans1_primary_value_unit,
			}
			trans1_level_unit,
			trans1_secondary_value_1_unit,		// same as trans1_level_unit
			trans1_sensor_unit,
			trans1_secondary_value_2_unit,		// same as trans1_sensor_unit

			trans1_st_rev,
			//trans1_calibration_type,				//pre_read_download_variables
			trans1_sensor_offset,
			trans1_sensor_low_limit,
			trans1_sensor_high_limit,

			trans1_level_offset,
			trans1_level_lo,
			trans1_level_hi,

			//trans1_lin_type,						//pre_read_download_variables
			IF (trans1_calibration_type != 3)
			{
				trans1_lin_diameter,
				trans1_lin_volume,
			}

#ifndef NO_trans1_max_sensor_value 
			//trans1_max_sensor_value,				//Online
#endif

#ifdef OPT_LINTABLE
			//trans1_tab_actual_number,				//pre_read_download_variables
			//trans1_tab_entry,						//OnlineDialog_linearization / SIPAST_Tables...
			trans1_tab_max_number,
			trans1_tab_min_number,
#endif
#ifndef NO_trans1_temperature_unit
			trans1_temperature_unit,
#endif
			trans1_cal_point_lo,
			trans1_cal_point_hi,

			// Sttzstellen
			IF (LIN_TABLE_USER)
			{
				IF (trans1_tab_coordinate_number_loc > 0) {
					trans1_tab_x_value_0,
					trans1_tab_y_value_0,
				}
				IF (trans1_tab_coordinate_number_loc > 1) {
					trans1_tab_x_value_1,
					trans1_tab_y_value_1,
				}
				IF (trans1_tab_coordinate_number_loc > 2) {
					trans1_tab_x_value_2,
					trans1_tab_y_value_2,
				}
				IF (trans1_tab_coordinate_number_loc > 3) {
					trans1_tab_x_value_3,
					trans1_tab_y_value_3,
				}
				IF (trans1_tab_coordinate_number_loc > 4) {
					trans1_tab_x_value_4,
					trans1_tab_y_value_4,
				}
				IF (trans1_tab_coordinate_number_loc > 5) {
					trans1_tab_x_value_5,
					trans1_tab_y_value_5,
				}
				IF (trans1_tab_coordinate_number_loc > 6) {
					trans1_tab_x_value_6,
					trans1_tab_y_value_6,
				}
				IF (trans1_tab_coordinate_number_loc > 7) {
					trans1_tab_x_value_7,
					trans1_tab_y_value_7,
				}
				IF (trans1_tab_coordinate_number_loc > 8) {
					trans1_tab_x_value_8,
					trans1_tab_y_value_8,
				}
				IF (trans1_tab_coordinate_number_loc > 9) {
					trans1_tab_x_value_9,
					trans1_tab_y_value_9,
				}
				IF (trans1_tab_coordinate_number_loc > 10) {
					trans1_tab_x_value_10,
					trans1_tab_y_value_10,
				}
				IF (trans1_tab_coordinate_number_loc > 11) {
					trans1_tab_x_value_11,
					trans1_tab_y_value_11,
				}
				IF (trans1_tab_coordinate_number_loc > 12) {
					trans1_tab_x_value_12,
					trans1_tab_y_value_12,
				}
				IF (trans1_tab_coordinate_number_loc > 13) {
					trans1_tab_x_value_13,
					trans1_tab_y_value_13,
				}
				IF (trans1_tab_coordinate_number_loc > 14) {
					trans1_tab_x_value_14,
					trans1_tab_y_value_14,
				}
				IF (trans1_tab_coordinate_number_loc > 15) {
					trans1_tab_x_value_15,
					trans1_tab_y_value_15,
				}
				IF (trans1_tab_coordinate_number_loc > 16) {
					trans1_tab_x_value_16,
					trans1_tab_y_value_16,
				}
				IF (trans1_tab_coordinate_number_loc > 17) {
					trans1_tab_x_value_17,
					trans1_tab_y_value_17,
				}
				IF (trans1_tab_coordinate_number_loc > 18) {
					trans1_tab_x_value_18,
					trans1_tab_y_value_18,
				}
				IF (trans1_tab_coordinate_number_loc > 19) {
					trans1_tab_x_value_19,
					trans1_tab_y_value_19,
				}
				IF (trans1_tab_coordinate_number_loc > 20) {
					trans1_tab_x_value_20,
					trans1_tab_y_value_20,
				}
			}

			/* TRANDSDUCER BLOCK, SPECIFIC PARAMETER	*/
			//trans1_emtpy_calibration_V0H1,		// OnlineDialogLevelCalibration
			//trans1_full_calibration_V0H2,			// OnlineDialogLevelCalibration
			trans1_display_format_V0H3,
			trans1_damping_V0H4,
			trans1_fail_safe_V0H7,

			IF ((trans1_calibration_type == 0) || (trans1_calibration_type == 2)) {
			 trans1_dry_calibration_unit_V3H1
			}

			IF (trans1_calibration_type != 3) {
				trans1_density_factor_V3H2,
				trans1_zero_offset_V3H3
			}
			//trans1_simulation_mode_V9H6,			// OnlineDialog_simulation_input_trans1
			trans1_full_density_VAH4,
			trans1_empty_pressure_VAH6,
			trans1_empty_density_VAH7,
			trans1_full_pressure_VAH8,



		/* FUNCTION BLOCK		*/
			func1_AI_st_rev,
#ifdef FUNC1_CHANNEL_LIST
			func1_AI_channel,
#endif
			func1_AI_pv_lower_range_value,	//	std_V0H5
			func1_AI_pv_upper_range_value,	//	std_V0H6
			func1_AI_out_unit,
			func1_AI_out_unit_text,
			func1_AI_out_decimal_point,
			func1_AI_out_lower_range_value,
			func1_AI_out_upper_range_value,
			func1_AI_pv_ftime,
			func1_AI_alarm_hys,
			func1_AI_hi_lim,
			func1_AI_lo_lim,
			func1_AI_hi_hi_lim,
			func1_AI_lo_lo_lim,
			func1_AI_FSafeType,
			func1_AI_FSafeValue,
			func1_AI_batch_id,
			func1_AI_batch_unit,
			func1_AI_batch_operation,
			func1_AI_batch_phase
		}	// IF (local_abort == 0)
	}
}



METHOD pre_write_upload_variables
{
	CLASS		INPUT;
	DEFINITION
	{
		int ret, i;
		//int i; //s.u.

		local_abort = 0; //kein Abbruch

		add_abort_method (meth_abort);

		// Schreibschutz abfragen
		ret = ReadCommand (read_phys_write_locking);
		if (ret >= ID_FC_ERROR)	process_abort();
		if (phys_write_locking != 2457) 
		{
			local_abort = 1;
			PUT_MESSAGE ([mess_write_protected]+[acknowledge_process_aborted]);
		}
		else
		{
			ret = WriteCommand(write_trans1_lin_type);
			if (ret >= ID_FC_ERROR)	process_abort();

			ret = WriteCommand(write_trans1_calibration_type);
			if (ret >= ID_FC_ERROR)	process_abort();
		}

		/* diese Schleife ist nach Aussage von E+H nicht notwendig!
		i = 0;
		do {
			ret = ReadCommand(read_phys_matrix_error_code);
			if (ret >= ID_FC_ERROR)	process_abort();

			i = i + 1;
			DELAY (2, "Device busy (E 103)|de|Gert ist beschftigt (E 103)");
		}
		while ((103 == ivar_value(phys_matrix_error_code)) && (i < 20));

		if (103 == phys_matrix_error_code) {
			ACKNOWLEDGE ([ack_phys_matrix_error_code]);
		}
		*/
	}
}


MENU upload_variables
{
	LABEL		[menu_load_to_device];
	PRE_WRITE_ACTIONS
	{
		pre_write_upload_variables
	}
	ITEMS
	{

		IF (local_abort == 0 /*&& phys_matrix_error_code != 103*/)
		{
		/* PHYSICAL BLOCK, STANDARD PARAMETER	*/
			phys_tag_desc,
		/* PHYSICAL BLOCK, ADDITIONAL PARAMETER	*/
			phys_descriptor,
			phys_message,
			phys_ident_number
			phys_install_date,

		/* PHYSICAL BLOCK, SPECIFIC PARAMETER	*/
			//phys_matrix_error_code,				//READ_ONLY
			phys_matrix_last_error_code,
			//phys_bus_address,						//READ_ONLY
			//phys_matrix_device_software_nr,		//READ_ONLY
			//std_V6H1,								//Menu phys_pa_set_unit_to_bus,
			//phys_pa_input_value,					//READ_ONLY
			//phys_pa_input_value_ui1,				//READ_ONLY
			//phys_pa_input_value_ui2,				//Commuwin Parameter
			phys_pa_select_v0h0,
			//phys_pa_profile_rev,					//READ_ONLY
			phys_pa_select_second_cyc_val,

		/* TRANDSDUCER BLOCK, STANDARD PARAMETER	*/
		/* TRANDSDUCER BLOCK, ADDITIONAL PARAMETER	*/
			trans1_primary_value_unit,

			IF (trans1_calibration_type != 3)
			{
				//IF (trans1_calibration_type != 2)
				//{
				//	trans1_primary_value_unit,
				//}
				trans1_volume_unit_VAH3,//trans1_primary_value_unit,
			}
			trans1_level_unit,
			//trans1_secondary_value_1_unit,		// same as trans1_level_unit
			trans1_sensor_unit,
			//trans1_secondary_value_2_unit,		// same as trans1_sensor_unit

#ifndef NO_trans1_temperature_unit
			trans1_temperature_unit,
#endif
			IF ((trans1_calibration_type == 0) || (trans1_calibration_type == 2)) {
			 trans1_dry_calibration_unit_V3H1
			}

			//trans1_calibration_type,			//pre_write_upload_variables
			//trans1_lin_type,					//pre_write_upload_variables


			//trans1_level_lo, //nur lesbar, sonst Gerte-Fehler
			//trans1_level_hi, //nur lesbar, sonst Gerte-Fehler
			trans1_sensor_offset,
			trans1_level_offset,

			IF (trans1_calibration_type != 3)
			{
				trans1_lin_diameter,
				trans1_lin_volume,
				trans1_density_factor_V3H2,
			}

			//trans1_emtpy_calibration_V0H1,		// OnlineDialogLevelCalibration
			//trans1_full_calibration_V0H2,			// OnlineDialogLevelCalibration
			trans1_display_format_V0H3,
			trans1_damping_V0H4,
			//std_V3H6,					// OnlineDialog_linearization
			trans1_fail_safe_V0H7,

			IF (trans1_calibration_type != 3) {
				trans1_density_factor_V3H2,
				trans1_zero_offset_V3H3
			}
			//trans1_simulation_mode_V9H6,			// OnlineDialog_simulation_input_trans1

#ifdef OPT_LINTABLE
			//trans1_tab_entry,					//OnlineDialog_linearization
#endif
/*			IF (LIN_TABLE_USER)
			{
				IF (trans1_tab_coordinate_number_loc > 0) {
					trans1_tab_x_value_0,
					trans1_tab_y_value_0,
				}
				IF (trans1_tab_coordinate_number_loc > 1) {
					trans1_tab_x_value_1,
					trans1_tab_y_value_1,
				}
				IF (trans1_tab_coordinate_number_loc > 2) {
					trans1_tab_x_value_2,
					trans1_tab_y_value_2,
				}
				IF (trans1_tab_coordinate_number_loc > 3) {
					trans1_tab_x_value_3,
					trans1_tab_y_value_3,
				}
				IF (trans1_tab_coordinate_number_loc > 4) {
					trans1_tab_x_value_4,
					trans1_tab_y_value_4,
				}
				IF (trans1_tab_coordinate_number_loc > 5) {
					trans1_tab_x_value_5,
					trans1_tab_y_value_5,
				}
				IF (trans1_tab_coordinate_number_loc > 6) {
					trans1_tab_x_value_6,
					trans1_tab_y_value_6,
				}
				IF (trans1_tab_coordinate_number_loc > 7) {
					trans1_tab_x_value_7,
					trans1_tab_y_value_7,
				}
				IF (trans1_tab_coordinate_number_loc > 8) {
					trans1_tab_x_value_8,
					trans1_tab_y_value_8,
				}
				IF (trans1_tab_coordinate_number_loc > 9) {
					trans1_tab_x_value_9,
					trans1_tab_y_value_9,
				}
				IF (trans1_tab_coordinate_number_loc > 10) {
					trans1_tab_x_value_10,
					trans1_tab_y_value_10,
				}
				IF (trans1_tab_coordinate_number_loc > 11) {
					trans1_tab_x_value_11,
					trans1_tab_y_value_11,
				}
				IF (trans1_tab_coordinate_number_loc > 12) {
					trans1_tab_x_value_12,
					trans1_tab_y_value_12,
				}
				IF (trans1_tab_coordinate_number_loc > 13) {
					trans1_tab_x_value_13,
					trans1_tab_y_value_13,
				}
				IF (trans1_tab_coordinate_number_loc > 14) {
					trans1_tab_x_value_14,
					trans1_tab_y_value_14,
				}
				IF (trans1_tab_coordinate_number_loc > 15) {
					trans1_tab_x_value_15,
					trans1_tab_y_value_15,
				}
				IF (trans1_tab_coordinate_number_loc > 16) {
					trans1_tab_x_value_16,
					trans1_tab_y_value_16,
				}
				IF (trans1_tab_coordinate_number_loc > 17) {
					trans1_tab_x_value_17,
					trans1_tab_y_value_17,
				}
				IF (trans1_tab_coordinate_number_loc > 18) {
					trans1_tab_x_value_18,
					trans1_tab_y_value_18,
				}
				IF (trans1_tab_coordinate_number_loc > 19) {
					trans1_tab_x_value_19,
					trans1_tab_y_value_19,
				}
				IF (trans1_tab_coordinate_number_loc > 20) {
					trans1_tab_x_value_20,
					trans1_tab_y_value_20,
				}
			}
end Bi V1.2*/
		/* FUNCTION BLOCK, STANDARD PARAMETER		*/
		/* FUNCTION BLOCK, ADDITIONAL PARAMETER		*/
	#ifdef FUNC1_CHANNEL_LIST
			func1_AI_channel,
	#endif
			func1_AI_out_unit,
			func1_AI_out_unit_text,
			func1_AI_pv_upper_range_value,	//	std_V0H6
			func1_AI_pv_lower_range_value,	//	std_V0H5
			func1_AI_out_upper_range_value,
			func1_AI_out_lower_range_value,
			func1_AI_pv_ftime,
			func1_AI_alarm_hys,
			func1_AI_hi_lim,
			func1_AI_lo_lim,
			func1_AI_hi_hi_lim,
			func1_AI_lo_lo_lim,
			func1_AI_FSafeType,
			func1_AI_FSafeValue,
			func1_AI_out_decimal_point,
			func1_AI_batch_id,
			func1_AI_batch_unit,
			func1_AI_batch_operation,
			func1_AI_batch_phase,
		} // IF (local_abort == 0)
	}
}