/*----------------------------------------------------------------------------------*/
/*	Copyright (C) Endress+Hauser Metechnik GmbH+Co (2000). All Rights Reserved		*/
/*	Product:		SIMATIC PDM														*/
/*                                                          						*/
/*	Device:		PRESSURE DEVICE for PROFIBUS PA										*/
/*	Description:	Device Description												*/
/*	Dictionary:	SIPADC01.dct														*/
/*                                                          						*/
/*  $Revision:1.2$									*/
/*  $Date: 06.02.2002									*/
/*  Obere Revision fr QVCS, untere fr DD, unten die aktuelle angeben 			*/ 
/*  Revision:1.2									*/
/*  Date: 06.02.2002									*/
/*----------------------------------------------------------------------------------*/
/* Date:                09.05.2001													*/
/* Author:              J. Flegel / ICS GmbH										*/
/* Changed Function(s): Change001 corrections									*/
/*----------------------------------------------------------------------------------*/
/* Date:                06.02.2002													*/
/* Author:              Frank Birgel / Process Solutions										*/
/* Changed Function(s): Bi V1.2, herstellerspezifische Parameter aus Profilansicht entfernt*/
/*----------------------------------------------------------------------------------*/

VARIABLE trans1_emtpy_calibration_V0H1
{
	LABEL		[std_V0H1];
	HELP		[std_V0H1_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	DEF_VALID_IF_CAL_TYPE_IS_LEVEL
}

VARIABLE trans1_full_calibration_V0H2
{
	LABEL		[std_V0H2];
	HELP		[std_V0H2_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	100.0;
	}
	DEF_VALID_IF_NOT_CAL_TYPE_IS_PRESS
}

VARIABLE trans1_display_format_V0H3
{
	LABEL		[std_V0H3];
	HELP		[std_V0H3_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER
	{
		DEFAULT_VALUE	1;
		MAX_VALUE		3;
	}
}

VARIABLE trans1_damping_V0H4
{
	LABEL		[std_V0H4];
	HELP		[std_V0H4_help];
//	LABEL		[trans_damping];
//	HELP		[trans_damping_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	1;
	}
	CONSTANT_UNIT	[sec];
}

VARIABLE trans1_fail_safe_V0H7
{
	LABEL		[std_V0H7];
	HELP		[std_V0H7_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED
	{
		DEFAULT_VALUE	1;
		{	0,	[enum_eh_fail_safe_min]		},
		{	1,	[enum_eh_fail_safe_max]		},
		{	2,	[enum_eh_fail_safe_hold]	}
	}
}

VARIABLE trans1_lin_tab_level_V2H2
{
	LABEL		[std_V2H2];
	HELP		[std_V2H2_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	CONSTANT_UNIT	[unit_1342];
	HANDLING	
		IF (trans1_lin_type == 240) //manuell
		{
			READ & WRITE;
		}
		ELSE
		{
			READ;
		}
}

VARIABLE trans1_lin_tab_volume_V2H3
{
	LABEL		[std_V2H3];
	HELP		[std_V2H3_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	CONSTANT_UNIT	[unit_1342];
	HANDLING
		IF ((trans1_lin_type == 240) || (trans1_lin_type == 241)
		    ||(trans1_lin_type == 20)) //manuell o. halbautom. 
		{
			READ & WRITE;
		}
		ELSE
		{
			READ;
		}
}

VARIABLE trans1_dry_calibration_unit_V3H1
{
	LABEL		[std_V3H1];
	HELP		[std_V3H1_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEF_TRANS_DRY_CALIBRATION_UNIT
	}
	DEF_VALID_IF_CAL_TYPE_IS_DRY_CAL
}

VARIABLE trans1_density_factor_V3H2
{
	LABEL		[std_V3H2];
	HELP		[std_V3H2_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	1.0;
	}
	DEF_VALID_IF_NOT_CAL_TYPE_IS_PRESS
}

VARIABLE trans1_zero_offset_V3H3
{
	LABEL		[std_V3H3];
	HELP		[std_V3H3_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	DEF_VALID_IF_NOT_CAL_TYPE_IS_PRESS
}

VARIABLE trans1_simulation_mode_V9H6
{
	LABEL		[std_V9H6];
	HELP		[std_V9H6_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED
	{
		DEFAULT_VALUE 0;

		{	0,	[off]	},
		{	1,	[enum_eh_press]	},
		IF (trans1_calibration_type != 3)
		{
			{	2,	[enum_eh_level]	},
			{	3,	[enum_eh_volume]}
		}

	}
}

VARIABLE trans1_simulation_value_V9H7
{
	LABEL		[std_V9H7];
	HELP		[std_V9H7_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE 0.0;
	}
	
	VALIDITY	IF (trans1_simulation_mode_V9H6 != 0)
	{
		TRUE;
	}
	ELSE
	{
		FALSE;
	}

	HANDLING	IF (trans1_simulation_mode_V9H6 != 0)
	{
		READ & WRITE;
	}
	ELSE
	{
		READ;
	}
}

VARIABLE trans1_volume_unit_VAH3	// = trans1_primary_value_unit
{
	LABEL		[std_VAH3];
	HELP		[std_VAH3_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEF_TRANS_LEVEL_UNIT //DEF_TRANS_PRIMARY_VALUE_UNIT
	}
	DEF_VALID_IF_NOT_CAL_TYPE_IS_PRESS
}

VARIABLE trans1_full_density_VAH4
{
	LABEL		[std_VAH4];
	HELP		[std_VAH4_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	1.0;
	}
	HANDLING	READ;
}

VARIABLE trans1_empty_pressure_VAH6
{
	LABEL		[std_VAH6];
	HELP		[std_VAH6_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	HANDLING	READ;
}

VARIABLE trans1_empty_density_VAH7
{
	LABEL		[std_VAH7];
	HELP		[std_VAH7_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	1.0;
	}
	HANDLING	READ;
}

VARIABLE trans1_full_pressure_VAH8
{
	LABEL		[std_VAH8];
	HELP		[std_VAH8_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	400.0;
	}
	HANDLING	READ;
}
/*
MENU Tab_s_spec_trans1_parameter
{
	LABEL		[menu_spec_trans_parameter];
	ITEMS
	{
		std_V0H0,//Mewert,
		std_V0H1,//trans1_emtpy_calibration_V0H1,
		std_V0H2,//trans1_full_calibration_V0H2,
		trans1_display_format_V0H3,
		trans1_damping_V0H4,
		trans1_fail_safe_V0H7,
		std_V2H2,//trans1_lin_tab_level_V2H2
		std_V2H3,//trans1_lin_tab_volume_V2H3
		trans1_dry_calibration_unit_V3H1,
		trans1_density_factor_V3H2,
		trans1_zero_offset_V3H3,
		std_V9H6,//trans1_simulation_mode_V9H6,
		std_V9H7,//trans1_simulation_value_V9H7,
		profil_par.std_VAH2,//trans1_level_unit,
		trans1_volume_unit_VAH3,//profil_par.std_VAH3,
		trans1_full_density_VAH4,
		trans1_empty_pressure_VAH6,
		trans1_empty_density_VAH7,
		trans1_full_pressure_VAH8
	}
}
06.02.2002 Bi V1.2*/
//Change001 Begin
/*
MENU Tab_m_spec_trans1_parameter
{
	LABEL		[menu_spec_trans_parameter];
	ITEMS
	{
		std_V0H0,
		std_V0H1,
		std_V0H2,
		trans1_display_format_V0H3				(READ_ONLY),
		trans1_damping_V0H4						(READ_ONLY),
		trans1_fail_safe_V0H7					(READ_ONLY),
		std_V2H2,//trans1_lin_tab_level_V2H2
		std_V2H3,//trans1_lin_tab_volume_V2H3
		trans1_dry_calibration_unit_V3H1		(READ_ONLY),
		trans1_density_factor_V3H2				(READ_ONLY),
		trans1_zero_offset_V3H3					(READ_ONLY),
		trans1_simulation_mode_V9H6				(READ_ONLY),
		trans1_simulation_value_V9H7			(READ_ONLY),
		profil_par.std_VAH2						(READ_ONLY),//trans1_level_unit,
		trans1_volume_unit_VAH3					(READ_ONLY),//profil_par.std_VAH3,
		trans1_full_density_VAH4,
		trans1_empty_pressure_VAH6,
		trans1_empty_density_VAH7,
		trans1_full_pressure_VAH8
	}
}
//Change001 End
06.02.2002 Bi V1.2*/

/***********************************************************************/
/*    Unit relations                                                   */
/***********************************************************************/


/*******************************************************************************/
/*****	Commands  **************************************************************/
/*******************************************************************************/


COMMAND read_trans1_emtpy_calibration_V0H1
{
	BLOCK transducer_block_1;
	INDEX 58;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			//IF (trans1_calibration_type == 1)
			//{
				trans1_emtpy_calibration_V0H1
			//}
		}
	}
}

COMMAND write_trans1_emtpy_calibration_V0H1
{
	BLOCK transducer_block_1;
	INDEX 58;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_emtpy_calibration_V0H1
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_full_calibration_V0H2
{
	BLOCK transducer_block_1;
	INDEX 59;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			//IF (trans1_calibration_type != 3)
			//{
			trans1_full_calibration_V0H2
			//}
		}
	}
}

COMMAND write_trans1_full_calibration_V0H2
{
	BLOCK transducer_block_1;
	INDEX 59;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_full_calibration_V0H2
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_display_format_V0H3
{
	BLOCK transducer_block_1;
	INDEX 60;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_display_format_V0H3
		}
	}
}

COMMAND write_trans1_display_format_V0H3
{
	BLOCK transducer_block_1;
	INDEX 60;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_display_format_V0H3
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_damping_V0H4
{
	BLOCK transducer_block_1;
	INDEX 61;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_damping_V0H4
		}
	}
}

COMMAND write_trans1_damping_V0H4
{
	BLOCK transducer_block_1;
	INDEX 61;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_damping_V0H4
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_fail_safe_V0H7
{
	BLOCK transducer_block_1;
	INDEX 62;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_fail_safe_V0H7
		}
	}
}

COMMAND write_trans1_fail_safe_V0H7
{
	BLOCK transducer_block_1;
	INDEX 62;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_fail_safe_V0H7
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_lin_tab_level_V2H2
{
	BLOCK transducer_block_1;
	INDEX 63;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_lin_tab_level_V2H2
		}
	}
}

COMMAND write_trans1_lin_tab_level_V2H2
{
	BLOCK transducer_block_1;
	INDEX 63;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_lin_tab_level_V2H2
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_lin_tab_volume_V2H3
{
	BLOCK transducer_block_1;
	INDEX 64;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_lin_tab_volume_V2H3
		}
	}
}

COMMAND write_trans1_lin_tab_volume_V2H3
{
	BLOCK transducer_block_1;
	INDEX 64;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_lin_tab_volume_V2H3
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_dry_calibration_unit_V3H1
{
	BLOCK transducer_block_1;
	INDEX 65;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_dry_calibration_unit_V3H1
		}
	}
}

COMMAND write_trans1_dry_calibration_unit_V3H1
{
	BLOCK transducer_block_1;
	INDEX 65;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_dry_calibration_unit_V3H1
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_density_factor_V3H2
{
	BLOCK transducer_block_1;
	INDEX 66;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_density_factor_V3H2
		}
	}
}

COMMAND write_trans1_density_factor_V3H2
{
	BLOCK transducer_block_1;
	INDEX 66;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_density_factor_V3H2
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_zero_offset_V3H3
{
	BLOCK transducer_block_1;
	INDEX 67;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_zero_offset_V3H3
		}
	}
}

COMMAND write_trans1_zero_offset_V3H3
{
	BLOCK transducer_block_1;
	INDEX 67;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_zero_offset_V3H3
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_simulation_mode_V9H6
{
	BLOCK transducer_block_1;
	INDEX 68;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_simulation_mode_V9H6
		}
	}
}

COMMAND write_trans1_simulation_mode_V9H6
{
	BLOCK transducer_block_1;
	INDEX 68;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_simulation_mode_V9H6
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_simulation_value_V9H7
{
	BLOCK transducer_block_1;
	INDEX 69;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_simulation_value_V9H7
		}
	}
}

COMMAND write_trans1_simulation_value_V9H7
{
	BLOCK transducer_block_1;
	INDEX 69;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_simulation_value_V9H7
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_volume_unit_VAH3
{
	BLOCK transducer_block_1;
	INDEX 70;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_volume_unit_VAH3
		}
	}
}

COMMAND write_trans1_volume_unit_VAH3
{
	BLOCK transducer_block_1;
	INDEX 70;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_volume_unit_VAH3
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_empty_pressure_VAH6
{
	BLOCK transducer_block_1;
	INDEX 71;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_empty_pressure_VAH6
		}
	}
}

COMMAND read_trans1_empty_density_VAH7
{
	BLOCK transducer_block_1;
	INDEX 72;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_empty_density_VAH7
		}
	}
}

COMMAND read_trans1_full_pressure_VAH8
{
	BLOCK transducer_block_1;
	INDEX 73;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_full_pressure_VAH8
		}
	}
}

COMMAND read_trans1_full_density_VAH4
{
	BLOCK transducer_block_1;
	INDEX 74;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_full_density_VAH4
		}
	}
}

